==> igniteui-react-inputs-18.7.4.tgz: package/esm2015/lib/XIconBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { enumGetBox, markType } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { SvgIconRegistry } from "igniteui-react-core";
import { stringStartsWith } from "igniteui-react-core";
import { trimStart } from "igniteui-react-core";
/**
 * @hidden
 */
export let XIconBridge = /*@__PURE__*/ (() => {
    class XIconBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.u = "default";
            this.v = null;
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 16: return this.v;
                case 15: return this.u;
                case 18: return enumGetBox(BaseControlTheme_$type, c.k);
                case 44: return c.an;
                case 45: return c.ao;
                case 46: return c.ap;
                case 47: return c.am;
                case 48: return c.aq;
                case 49: return c.ai;
                case 62: return c.e;
                case 63: return c.f;
                case 64: return c.al;
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            super.setValue(a, b, c);
            let d = a;
            switch (b) {
                case 15:
                    {
                        this.u = c;
                        this.w(d);
                    }
                    break;
                case 16:
                    {
                        this.v = c;
                        this.w(d);
                    }
                    break;
                case 44:
                    d.an = c;
                    break;
                case 45:
                    d.ao = c;
                    break;
                case 46:
                    d.ap = c;
                    break;
                case 47:
                    d.am = c;
                    break;
                case 48:
                    d.aq = c;
                    break;
                case 49:
                    d.ai = c;
                    break;
                case 62:
                    d.e = c;
                    break;
                case 63:
                    d.f = c;
                    break;
                case 64:
                    d.al = c;
                    break;
            }
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 24: return b;
            }
            return super.getTargetForProperty(a, b);
        }
        w(a) {
            a.svg = null;
            a.svgPath = null;
            a.b = null;
            let b = SvgIconRegistry.instance.getSvgPathString(this.u, this.v);
            if (b != null) {
                if (stringStartsWith(trimStart(b, ' ', '\n', '\r', '\t'), "<svg")) {
                    a.svg = b;
                }
                else {
                    a.svgPath = b;
                }
                return;
            }
            let c = SvgIconRegistry.instance.getSvgPathsString(this.u, this.v);
            if (c != null) {
                a.b = c;
                return;
            }
            let d = SvgIconRegistry.instance.getDataURLString(this.u, this.v);
            if (d != null) {
                a.a9 = d;
                return;
            }
            let e = SvgIconRegistry.instance.getIconSource(this.u, this.v);
            if (e != null) {
                a.aw = e;
            }
        }
        exportVisualData(a) {
            return a.av();
        }
    }
    XIconBridge.$t = /*@__PURE__*/ markType(XIconBridge, 'XIconBridge', XComponentBridge.$);
    return XIconBridge;
})();

==> igniteui-react-inputs-18.9.1.tgz: package/esm2015/lib/XIconBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { enumGetBox, markType } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { SvgIconRegistry } from "igniteui-react-core";
import { stringStartsWith } from "igniteui-react-core";
import { trimStart } from "igniteui-react-core";
/**
 * @hidden
 */
export let XIconBridge = /*@__PURE__*/ (() => {
    class XIconBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.u = "default";
            this.v = null;
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 16: return this.v;
                case 15: return this.u;
                case 18: return enumGetBox(BaseControlTheme_$type, c.m);
                case 44: return c.aq;
                case 45: return c.ar;
                case 46: return c.as;
                case 47: return c.ap;
                case 48: return c.at;
                case 49: return c.al;
                case 63: return c.e;
                case 64: return c.f;
                case 65: return c.ao;
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            super.setValue(a, b, c);
            let d = a;
            switch (b) {
                case 15:
                    {
                        this.u = c;
                        this.w(d);
                    }
                    break;
                case 16:
                    {
                        this.v = c;
                        this.w(d);
                    }
                    break;
                case 44:
                    d.aq = c;
                    break;
                case 45:
                    d.ar = c;
                    break;
                case 46:
                    d.as = c;
                    break;
                case 47:
                    d.ap = c;
                    break;
                case 48:
                    d.at = c;
                    break;
                case 49:
                    d.al = c;
                    break;
                case 63:
                    d.e = c;
                    break;
                case 64:
                    d.f = c;
                    break;
                case 65:
                    d.ao = c;
                    break;
            }
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 24: return b;
            }
            return super.getTargetForProperty(a, b);
        }
        w(a) {
            a.svg = null;
            a.svgPath = null;
            a.b = null;
            a.bg = null;
            a.a1 = null;
            let b = SvgIconRegistry.instance.getSvgPathString(this.u, this.v);
            if (b != null) {
                if (stringStartsWith(trimStart(b, ' ', '\n', '\r', '\t'), "<svg")) {
                    a.svg = b;
                }
                else {
                    a.svgPath = b;
                }
                return;
            }
            let c = SvgIconRegistry.instance.getSvgPathsString(this.u, this.v);
            if (c != null) {
                a.b = c;
                return;
            }
            let d = SvgIconRegistry.instance.getDataURLString(this.u, this.v);
            if (d != null) {
                a.bg = d;
                return;
            }
            let e = SvgIconRegistry.instance.getIconSource(this.u, this.v);
            if (e != null) {
                a.a1 = e;
            }
        }
        exportVisualData(a) {
            return a.a0();
        }
    }
    XIconBridge.$t = /*@__PURE__*/ markType(XIconBridge, 'XIconBridge', XComponentBridge.$);
    return XIconBridge;
})();
